#source: b-twoinsn.s
#source: b-post1.s
#source: b-nosym.s
#ld: --oformat binary
#objcopy_linked_file:
#objdump: -st

.*:     file format mmo

SYMBOL TABLE:
0+4 g       \.text Main

Contents of section \.text:
 0000 e3fd0001 e3fd0004                    .*
